magneticalc.QtWidgets2.QPushButton2.QPushButton2

# ``magneticalc`.`QtWidgets2`.`QPushButton2`.`QPushButton2``

class documentation

`class QPushButton2(QPushButton):`

Constructor: `QPushButton2(text, icon, clicked, css)`

View In Hierarchy

QPushButton2 class.

Method | `__init__` | Initializes a QPushButton.

def __init__(self, text: `str`, icon: `str`, clicked: `Callable | None` = None, css: `str | None` = None):

Initializes a QPushButton.

Parameters
text: `str` | Text
icon: `str` | Icon name
clicked: `Callable | None` | Callback for button click
css: `str | None` | Additional CSS (optional)